==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/SaveAs/ts/SaveAs_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../SaveAs.js" line="+32"/>
        <source>Load/Save</source>
        <translation>Laden/Speichern</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters</source>
        <translation>Keine Exportfilter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Keine Exportfilter wurden gefunden. Abbruch...</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter...</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Default format:</source>
        <translation>Standardformat:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Warnung anzeigen beim Speichern in einem Dateiformat, welches keine 24bit Farben unterstützt</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/SaveAs/ts/SaveAs_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translation>Laden/Speichern</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Speichern unter</translation>
    </message>
    <message>
        <source>No export filters</source>
        <translation type="vanished">Keine Exportfilter</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Keine Exportfilter wurden gefunden. Abbruch...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter...</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Dateidialog</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Dateidialog des Systems verwenden</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Standardformat:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Warnung anzeigen beim Speichern in einem Dateiformat, welches keine 24bit Farben unterstützt</translation>
    </message>
</context>
</TS>
